@@ -8,7 +8,9 @@ use crate::parser::types::{
     OperationDefinition, OperationType, Selection, SelectionSet, TypeCondition, VariableDefinition,
 };
 use crate::registry::{self, MetaType, MetaTypeName};
-use crate::{InputType, Name, Pos, Positioned, ServerError, ServerResult, Variables};
+use crate::{
+    ErrorExtensionValues, InputType, Name, Pos, Positioned, ServerError, ServerResult, Variables,
+};
 
 #[doc(hidden)]
 pub struct VisitorContext<'a> {
@@ -37,10 +39,16 @@ impl<'a> VisitorContext<'a> {
     }
 
     pub(crate) fn report_error<T: Into<String>>(&mut self, locations: Vec<Pos>, msg: T) {
-        self.errors.push(RuleError {
-            locations,
-            message: msg.into(),
-        })
+        self.errors.push(RuleError::new(locations, msg, None));
+    }
+
+    pub(crate) fn report_error_with_extensions<T: Into<String>>(
+        &mut self,
+        locations: Vec<Pos>,
+        msg: T,
+        extensions: Option<ErrorExtensionValues>,
+    ) {
+        self.errors.push(RuleError::new(locations, msg, extensions));
     }
 
     pub(crate) fn append_errors(&mut self, errors: Vec<RuleError>) {
@@ -790,6 +798,21 @@ fn visit_inline_fragment<'a, V: Visitor<'a>>(
 pub(crate) struct RuleError {
     pub(crate) locations: Vec<Pos>,
     pub(crate) message: String,
+    pub(crate) extensions: Option<ErrorExtensionValues>,
+}
+
+impl RuleError {
+    pub(crate) fn new(
+        locations: Vec<Pos>,
+        msg: impl Into<String>,
+        extensions: Option<ErrorExtensionValues>,
+    ) -> Self {
+        Self {
+            locations,
+            message: msg.into(),
+            extensions,
+        }
+    }
 }
 
 impl Display for RuleError {
@@ -819,7 +842,7 @@ impl From<RuleError> for ServerError {
             message: e.message,
             locations: e.locations,
             path: Vec::new(),
-            extensions: None,
+            extensions: e.extensions,
         }
     }
 }
